@@ -6,7 +6,7 @@ use Mouse::Util::TypeConstraints;
 
 our $VERSION = '0.04';
 
-use base 'Elive::DAO::_Base';
+use parent 'Elive::DAO::_Base';
 
 use YAML::Syck;
 use Scalar::Util qw{weaken};
@@ -1083,6 +1083,9 @@ sub set {
 		    unless  Elive::Util::inspect_type($type)->is_ref;
 	    }
 
+	    die (ref($self)." - attempt to set attribute $_ to tainted data")
+		if Elive::Util::_tainted($value);
+
 	    $self->$_($value);
 	}
 	else {
@@ -1106,7 +1109,7 @@ sub _readback {
 
     my $results = $class->_get_results($som, $connection);
     #
-    # Check that the return response has our inserts
+    # Check that the return response has our inserts/updates
     #
     my $rows = $class->_process_results( $results );
     $class->_readback_check($sent_data, $rows, %opt);
@@ -1150,12 +1153,12 @@ provided. It is generated for you and returned with the newly created object.
 =cut
 
 sub insert {
-    my ($class, $insert_data, %opt) = @_;
+    my ($class, $_insert_data, %opt) = @_;
 
     my $connection = $opt{connection} || $class->connection
 	or die "not connected";
 
-    my %insert_data = %$insert_data;
+    my %insert_data = %$_insert_data;
     my %params = %{delete $opt{param} || {}};
 
     my $data_params = $class->_freeze({%insert_data, %params});
@@ -1166,7 +1169,7 @@ sub insert {
 
     my $som = $connection->call($command, %$data_params);
 
-    my @rows = $class->_readback($som, $insert_data, $connection, %opt);
+    my @rows = $class->_readback($som, $_insert_data, $connection, %opt);
 
     my @objs = (map {$class->construct( $_, connection => $connection )}
 		@rows);
