@@ -14,7 +14,7 @@ use Elive::Entity::MeetingParameters;
 use Elive::Entity::ServerParameters;
 use Elive::Entity::ParticipantList;
 
-use YAML;
+use YAML::Syck;
 
 =head1 NAME
 
